<?php
/**
 * Defines customizer options
 *
 * @package Customizer Library Demo
 */

function customizer_library_demo_options() {

	// Theme defaults
	$primary_color = '#4CAF50';
	$nav_bg_color = '#5f5f5f';

	$loop_style_choices = array(
		'choice-1' => 'List Layout',		
		'choice-2' => 'Grid Layout',
		'choice-3' => 'Blog Layout',
	);	

	// Stores all the controls that will be added
	$options = array();

	// Stores all the sections to be added
	$sections = array();

	// Stores all the panels to be added
	$panels = array();

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// More Examples
	$section = 'examples';

	// Arrays 

	$layout_choices = array(
		'choice-1' => 'Responsive Layout',
		'choice-2' => 'Fixed Layout'
	);

	$single_layout_choices = array(
		'choice-1' => 'Content / Sidebar',
		'choice-2' => 'Sidebar / Content / Sidebar'
	);

	$page_layout_choices = array(
		'choice-1' => 'Boxed',
		'choice-2' => 'Full Width'
	);

	$sections[] = array(
		'id' => $section,
		'title' => __( 'Theme Settings', 'course-pro' ),
		'priority' => '10'
	);

	$options['logo'] = array(
		'id' => 'logo',
		'label'   => __( 'Logo', 'course-pro' ),
		'section' => $section,
		'type'    => 'image',
		'default' => get_template_directory_uri().'/assets/img/logo.png'
	);

	$options['favicon'] = array(
		'id' => 'favicon',
		'label'   => __( 'Favicon', 'course-pro' ),
		'section' => $section,
		'type'    => 'image',
		'default' => ''
	);	
	
	$options['primary-color'] = array(
		'id' => 'primary-color',
		'label'   => __( 'Theme Primary Color', 'course-pro' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $primary_color // hex
	);

	$options['nav-bg-color'] = array(
		'id' => 'nav-bg-color',
		'label'   => __( 'Navigation Menu Background Color', 'course-pro' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $nav_bg_color // hex
	);

	$options['site-layout'] = array(
		'id' => 'site-layout',
		'label'   => __( 'Responsive Design', 'course-pro' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $layout_choices,
		'default' => 'choice-1'
	);

	$options['page-layout'] = array(
		'id' => 'page-layout',
		'label'   => __( 'Site Layout', 'course-pro' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $page_layout_choices,
		'default' => 'choice-1'
	);

	$options['single-post-layout'] = array(
		'id' => 'single-post-layout',
		'label'   => __( 'Single Post Layout', 'course-pro' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $single_layout_choices,
		'default' => 'choice-1'
	);

	$options['primary-font'] = array(
		'id' => 'primary-font',
		'label'   => __( 'Body Font', 'course-pro' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => customizer_library_get_font_choices(),
		'default' => 'Open Sans'
	);

	$options['secondary-font'] = array(
		'id' => 'secondary-font',
		'label'   => __( 'Heading Font', 'course-pro' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => customizer_library_get_font_choices(),
		'default' => 'Open Sans'
	);	
	$options['sticky-nav-on'] = array(
		'id' => 'sticky-nav-on',
		'label'   => __( 'Sticky header navigation', 'course-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);		

	$options['header-search-on'] = array(
		'id' => 'header-search-on',
		'label'   => __( 'Display header search form', 'course-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);	

	$options['header-cart-on'] = array(
		'id' => 'header-cart-on',
		'label'   => __( 'Display cart menu on header', 'course-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);	

	$options['mobile-nav-heading'] = array(
		'id' => 'mobile-nav-heading',
		'label'   => __( 'Mobile Menu Heading Text', 'course-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => __('Menu', 'course-pro'),
	);			

	$options['home-featured-on'] = array(
		'id' => 'home-featured-on',
		'label'   => __( 'Display featured content on homepage', 'course-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);	

	$options['featured-text'] = array(
		'id' => 'featured-text',
		'label'   => __( 'Featured Ribbon Text', 'course-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => __('Featured', 'course-pro'),
	);	

	$options['featured-num'] = array(
		'id' => 'featured-num',
		'label'   => __( 'Number of featured posts', 'course-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '3',		
	);	

	$options['home-loop-style'] = array(
		'id' => 'home-loop-style',
		'label'   => __( 'Home Posts Style', 'course-pro' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => $loop_style_choices,
		'default' => 'choice-2'
	);	

	$options['archive-loop-style'] = array(
		'id' => 'archive-loop-style',
		'label'   => __( 'Archive/Search Posts Style', 'course-pro' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => $loop_style_choices,
		'default' => 'choice-1'
	);		

	$options['recent-heading'] = array(
		'id' => 'recent-heading',
		'label'   => __( 'Recent content heading text', 'course-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => __('Recent Posts', 'course-pro'),
	);	

	$options['blog-excerpt-length'] = array(
		'id' => 'blog-excerpt-length',
		'label'   => __( 'Excerpt length of blog layout', 'course-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '40',		
	);	

	$options['grid-excerpt-length'] = array(
		'id' => 'grid-excerpt-length',
		'label'   => __( 'Excerpt length of grid layout', 'course-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '18',		
	);		

	$options['list-excerpt-length'] = array(
		'id' => 'list-excerpt-length',
		'label'   => __( 'Excerpt length of list layout', 'course-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '24',		
	);					

	$options['breadcrumbs-on'] = array(
		'id' => 'breadcrumbs-on',
		'label'   => __( 'Display breadcrumbs on single posts', 'course-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);

	$options['single-share-on'] = array(
		'id' => 'single-share-on',
		'label'   => __( 'Display share icons on single posts', 'course-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);

	$options['single-featured-on'] = array(
		'id' => 'single-featured-on',
		'label'   => __( 'Display featured image on single posts', 'course-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);	

	$options['author-box-on'] = array(
		'id' => 'author-box-on',
		'label'   => __( 'Display author box on single posts', 'course-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	
	$options['related-posts-on'] = array(
		'id' => 'related-posts-on',
		'label'   => __( 'Display related posts on single posts', 'course-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['footer-widgets-on'] = array(
		'id' => 'footer-widgets-on',
		'label'   => __( 'Display footer widgets', 'course-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['back-top-on'] = array(
		'id' => 'back-top-on',
		'label'   => __( 'Display "back to top" icon link on the site bottom', 'course-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['header-social-on'] = array(
		'id' => 'header-social-on',
		'label'   => __( 'Display social icons on site header', 'course-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => false,
	);	

	$options['facebook-url'] = array(
		'id' => 'facebook-url',
		'label'   => __( 'Your Facebook URL', 'course-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',		
	);

	$options['twitter-url'] = array(
		'id' => 'twitter-url',
		'label'   => __( 'Your Twitter URL', 'course-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',		
	);	

	$options['google-plus-url'] = array(
		'id' => 'google-plus-url',
		'label'   => __( 'Your Google+ URL', 'course-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',		
	);	

	$options['youtube-url'] = array(
		'id' => 'youtube-url',
		'label'   => __( 'Your YouTube URL', 'course-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',		
	);	

	$options['linkedin-url'] = array(
		'id' => 'linkedin-url',
		'label'   => __( 'Your LinkedIn URL', 'course-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',		
	);	

	$options['pinterest-url'] = array(
		'id' => 'pinterest-url',
		'label'   => __( 'Your Pinterest URL', 'course-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',		
	);	

	$options['rss-url'] = array(
		'id' => 'rss-url',
		'label'   => __( 'Your RSS feed URL', 'course-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',		
	);	

	$options['footer-credit'] = array(
		'id' => 'footer-credit',
		'label'   => __( 'Customize Site Footer Text/Link', 'course-pro' ),
		'section' => $section,
		'type'    => 'textarea',
		'default' => '&copy; ' . date("o") . ' <a href="' . home_url() .'">' . get_bloginfo('name') . '</a> - Theme by <a href="https://www.happythemes.com" target="_blank">HappyThemes</a>'
	);					

	//$options['example-range'] = array(
	//	'id' => 'example-range',
	//	'label'   => __( 'Example Range Input', 'course-pro' ),
	//	'section' => $section,
	//	'type'    => 'range',
	//	'input_attrs' => array(
	//      'min'   => 0,
	//        'max'   => 10,
	//        'step'  => 1,
	//       'style' => 'color: #0a0',
	//	)
	//);

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// Adds the panels to the $options array
	$options['panels'] = $panels;

	$customizer_library = Customizer_Library::Instance();
	$customizer_library->add_options( $options );

	// To delete custom mods use: customizer_library_remove_theme_mods();

}
add_action( 'init', 'customizer_library_demo_options' );